import * as React from 'react';
import { useControlledValue } from '../../hooks/useControlledValue/useControlledValue.js';
import 'date-fns';
import { isDayPickerSingle } from '../../types/isDayPickerSingle.js';
import { SelectSingleContext } from './SelectSingleContext.js';

function SelectSingleProviderInternal(_a) {
    var initialProps = _a.initialProps, children = _a.children;
    var _b = useControlledValue(initialProps.defaultSelected, initialProps.selected), selected = _b[0], setSelected = _b[1];
    var handleDayClick = function (day, dayModifiers, e) {
        var _a, _b;
        if (dayModifiers.selected && !initialProps.required) {
            setSelected(undefined);
            (_a = initialProps.onSelect) === null || _a === void 0 ? void 0 : _a.call(initialProps, undefined, day, dayModifiers, e);
            return;
        }
        setSelected(day);
        (_b = initialProps.onSelect) === null || _b === void 0 ? void 0 : _b.call(initialProps, day, day, dayModifiers, e);
    };
    var modifiers = { selected: [] };
    if (selected) {
        modifiers.selected = [selected];
    }
    var contextValue = {
        selected: selected,
        handleDayClick: handleDayClick,
        modifiers: modifiers
    };
    return (React.createElement(SelectSingleContext.Provider, { value: contextValue }, children));
}
/** Provides the values for the [[SelectSingleProvider]]. */
function SelectSingleProvider(props) {
    if (!isDayPickerSingle(props.initialProps)) {
        var emptyContextValue = {
            selected: undefined,
            modifiers: { selected: [] }
        };
        return (React.createElement(SelectSingleContext.Provider, { value: emptyContextValue }, props.children));
    }
    return (React.createElement(SelectSingleProviderInternal, { initialProps: props.initialProps, children: props.children }));
}

export { SelectSingleProvider, SelectSingleProviderInternal };
//# sourceMappingURL=SelectSingleProvider.js.map
